@@ -1,18 +1,16 @@
-# -*- coding: utf-8 -*-
 """
 Contracts to enforce loader objects
 """
-
-# Import python libs
 import asyncio
 import functools
 import inspect
 import os
 from collections import namedtuple
 from types import ModuleType
-from typing import Dict, Iterable, List
+from typing import Dict
+from typing import Iterable
+from typing import List
 
-# Import pop libs
 import pop.exc
 import pop.hub
 import pop.verify
@@ -40,7 +38,7 @@ class ContractedContext(
     ):  # pylint: disable=too-many-arguments
         if cache is None:
             cache = {}
-        return super(ContractedContext, cls).__new__(
+        return super().__new__(
             cls, func, list(args), kwargs, signature, ret, cache, ref
         )
 
@@ -129,7 +127,13 @@ class Wrapper:
         self.func = func
         self.ref = ref
         self.__name__ = name
-        self.signature = inspect.signature(self.func)
+        try:
+            self.signature = inspect.signature(self.func)
+        except ValueError:
+            # inspect.signature raises a ValueError only when a signature could not be provided.
+            # Some callables may not be introspectable in certain implementations of Python.
+            # For example, in CPython, some built-in functions defined in C provide no metadata about their arguments.
+            self.signature = None
         self._sig_errors = []
         self.__wrapped__ = func
 
@@ -155,10 +159,20 @@ class Contracted(Wrapper):
         func: functools.partial,
         ref: str,
         name: str,
+        implicit_hub: bool = True,
     ):
+        """
+        :param hub: The redistributed pop central hub
+        :param contracts: Contracts functions to add to the sub
+        :param func: The contracted function to call
+        :param ref: The reference to the function on the hub
+        :param name: An alias for the function
+        :param implicit_hub: True if a hub should be implicitly injected into the "call" method
+        """
         super().__init__(func, ref, name)
         self.hub = hub
         self.contracts = contracts or []
+        self.implicit_hub = implicit_hub
         self._load_contracts()
 
     def _get_contracts_by_type(self, contract_type: str = "pre") -> List[Wrapper]:
@@ -166,7 +180,7 @@ class Contracted(Wrapper):
         :param contract_type: One of "call", "pre", "post", or "sig"
         """
         matches = []
-        fn_contract_name = "{}_{}".format(contract_type, self.__name__)
+        fn_contract_name = f"{contract_type}_{self.__name__}"
         for contract in self.contracts:
             if hasattr(contract, fn_contract_name):
                 matches.append(getattr(contract, fn_contract_name))
@@ -192,7 +206,8 @@ class Contracted(Wrapper):
         )
 
     def __call__(self, *args, **kwargs):
-        args = (self.hub,) + args
+        if self.implicit_hub:
+            args = (self.hub,) + args
         if not self._has_contracts:
             return self.func(*args, **kwargs)
         contract_context = ContractedContext(
@@ -215,7 +230,8 @@ class Contracted(Wrapper):
 
 class ContractedAsyncGen(Contracted):
     async def __call__(self, *args, **kwargs):
-        args = (self.hub,) + args
+        if self.implicit_hub:
+            args = (self.hub,) + args
         if not self._has_contracts:
             async for chunk in self.func(*args, **kwargs):
                 yield chunk
@@ -249,7 +265,8 @@ class ContractedAsyncGen(Contracted):
 
 class ContractedAsync(Contracted):
     async def __call__(self, *args, **kwargs):
-        args = (self.hub,) + args
+        if self.implicit_hub:
+            args = (self.hub,) + args
         if not self._has_contracts:
             return await self.func(*args, **kwargs)
         contract_context = ContractedContext(
@@ -281,6 +298,7 @@ def create_contracted(
     func: functools.partial,
     ref: str,
     name: str,
+    implicit_hub: bool = True,
 ) -> Contracted:
     """
     Dynamically create the correct Contracted type
@@ -289,10 +307,11 @@ def create_contracted(
     :param func: The contracted function to call
     :param ref: The reference to the function on the hub
     :param name: The name of the module to get from the loader
+    :param implicit_hub: True if a hub should be implicitly injected into the "call" method
     """
     if asyncio.iscoroutinefunction(func):
-        return ContractedAsync(hub, contracts, func, ref, name)
+        return ContractedAsync(hub, contracts, func, ref, name, implicit_hub)
     elif inspect.isasyncgenfunction(func):
-        return ContractedAsyncGen(hub, contracts, func, ref, name)
+        return ContractedAsyncGen(hub, contracts, func, ref, name, implicit_hub)
     else:
-        return Contracted(hub, contracts, func, ref, name)
+        return Contracted(hub, contracts, func, ref, name, implicit_hub)
