@@ -18,6 +18,13 @@ import pop.loader
 import pop.scanner
 import pop.verify
 
+try:
+    import pytest_pop.mods
+
+    HAS_TESTING_LIBS = True
+except ImportError:
+    HAS_TESTING_LIBS = False
+
 EXT_SUFFIXES = tuple(importlib.machinery.EXTENSION_SUFFIXES)
 log = logging.getLogger(__name__)
 
@@ -49,7 +56,10 @@ class Hub:
         # Add the pop sub to the hub, this should always use pypath and
         # Should never be made dynamic. This is a core system sub and should
         # NOT be app-merged
-        self._subs["pop"] = Sub(self, "pop", pypath="pop.mods.pop")
+        pypaths = ["pop.mods.pop"]
+        if HAS_TESTING_LIBS:
+            pypaths.append("pytest_pop.mods")
+        self._subs["pop"] = Sub(self, "pop", pypath=pypaths)
         self._iter_subs = sorted(self._subs.keys())
         self._iter_ind = 0
         # Set up the conf OPT structure so it is always available
